Crate wrkflw_gitlab

Crate wrkflw_gitlab 

Structs

RepoInfo
Information about a GitLab repository

Enums

GitlabError

Functions

get_repo_info
Extract repository information from the current git repository for GitLab
list_pipelines
Get the list of available pipeline files in the repository
trigger_pipeline
Trigger a pipeline on GitLab